@@ -2,9 +2,6 @@ package VCI::VCS::Bzr::Project;
 use Moose;
 
 use Path::Abstract::Underload;
-use VCI::VCS::Bzr::Directory;
-use VCI::VCS::Bzr::File;
-use VCI::VCS::Bzr::History;
 
 extends 'VCI::Abstract::Project';
 
@@ -17,9 +14,9 @@ sub BUILD {
 sub _build_history {
     my $self = shift;
     my $full_path = $self->repository->root . $self->name;
-    my $xml_string = $self->repository->vci->x_do(
-        args => [qw(log --xml), $full_path]);
-    return VCI::VCS::Bzr::History->x_from_xml($xml_string, $self);
+    my $xml_string = $self->vci->x_do(
+        args => [qw(log --show-ids --xml), $full_path]);
+    return $self->history_class->x_from_xml($xml_string, $self);
 }
 
 __PACKAGE__->meta->make_immutable;
