@@ -2,8 +2,6 @@ package VCI::VCS::Bzr::Repository;
 use Moose;
 use MooseX::Method;
 
-use VCI::VCS::Bzr::Project;
-
 extends 'VCI::Abstract::Repository';
 
 sub BUILD { shift->_root_always_ends_with_slash }
@@ -15,8 +13,8 @@ sub _build_projects {
     my $branch_names = $self->vci->x_do(args => ['branches', $self->root]);
     my @projects;
     foreach my $branch (split("\n", $branch_names)) {
-        push(@projects, VCI::VCS::Bzr::Project->new(name => $branch,
-                                                    repository => $self));
+        push(@projects, $self->project_class->new(name => $branch,
+                                                  repository => $self));
     }
     return \@projects;
 }
