@@ -1,8 +1,6 @@
 package VCI::VCS::Git::Diff;
 use Moose;
 
-use VCI::Abstract::Diff::File;
-
 extends 'VCI::Abstract::Diff';
 
 sub _transform_filename {
@@ -11,4 +9,6 @@ sub _transform_filename {
     return $name;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
